@@ -20,6 +20,7 @@ import logging
 from cliff.lister import Lister
 
 from service_registry_cli.utils import BaseListCommand, get_client
+from service_registry_cli.utils import format_metadata, format_timestamp
 
 
 class ListCommand(BaseListCommand, Lister):
@@ -30,10 +31,24 @@ class ListCommand(BaseListCommand, Lister):
 
     def take_action(self, parsed_args):
         client = get_client(parsed_args)
-        values = client.sessions.list()['values']
+        marker = parsed_args.marker if parsed_args.marker else None
+        limit = parsed_args.limit if parsed_args.limit else None
+
+        result = client.sessions.list(marker=marker, limit=limit)
+        values = result['values']
+        metadata = result['metadata']
+        limit, marker, next_marker = metadata['limit'], metadata['marker'], \
+            metadata['next_marker']
+
+        # Hack
+        parsed_args.returned_limit = limit
+        parsed_args.returned_marker = marker
+        parsed_args.returned_next_marker = next_marker
+
         session_tuples = [(value['id'],
                           value['heartbeat_timeout'],
-                          value['last_seen'])
+                          format_timestamp(value['last_seen']),
+                          format_metadata(value['metadata']))
                           for value in values]
-        return (('Session ID', 'Heartbeat Timeout', 'Last Seen'),
+        return (('Session ID', 'Heartbeat Timeout', 'Last Seen', 'Metadata'),
                 session_tuples)
